brian2genn
==========

Brian 2 frontend to the GeNN simulator

Please note that this package is still under development and has not
yet been officially released. It currently requires the latest version
of GeNN from its development branch (see https://github.com/genn-team/genn).

[![Build status](https://ci.appveyor.com/api/projects/status/8noa3jonx1xlil2k/branch/master?svg=true)](https://ci.appveyor.com/project/brianteam/brian2genn/branch/master)
[![Build Status](https://travis-ci.org/brian-team/brian2genn.svg?branch=master)](https://travis-ci.org/brian-team/brian2genn)
